==> site-0.23.10.Final.zip: src/main/java/org/jboss/tools/rsp/server/wildfly/servertype/impl/ServerTypeStringConstants.java <==
/*******************************************************************************
 * Copyright (c) 2018-2019 Red Hat, Inc. Distributed under license by Red Hat, Inc.
 * All rights reserved. This program is made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/epl-v20.html
 * 
 * Contributors: Red Hat, Inc.
 ******************************************************************************/
package org.jboss.tools.rsp.server.wildfly.servertype.impl;

import org.jboss.tools.rsp.server.wildfly.beans.impl.IServerConstants;

public interface ServerTypeStringConstants {
	// NEW_SERVER_ADAPTER 
	public static final String WF22_ID = IServerConstants.SERVER_WILDFLY_220;
	public static final String WF22_NAME = "WildFly 22.x";
	public static final String WF22_DESC = "A server adapter capable of discovering and controlling a WildFly 22.x runtime instance.";

	public static final String WF21_ID = IServerConstants.SERVER_WILDFLY_210;
	public static final String WF21_NAME = "WildFly 21.x";
	public static final String WF21_DESC = "A server adapter capable of discovering and controlling a WildFly 21.x runtime instance.";

	public static final String WF20_ID = IServerConstants.SERVER_WILDFLY_200;
	public static final String WF20_NAME = "WildFly 20.x";
	public static final String WF20_DESC = "A server adapter capable of discovering and controlling a WildFly 20.x runtime instance.";

	public static final String WF19_ID = IServerConstants.SERVER_WILDFLY_190;
	public static final String WF19_NAME = "WildFly 19.x";
	public static final String WF19_DESC = "A server adapter capable of discovering and controlling a WildFly 19.x runtime instance.";

	public static final String WF18_ID = IServerConstants.SERVER_WILDFLY_180;
	public static final String WF18_NAME = "WildFly 18.x";
	public static final String WF18_DESC = "A server adapter capable of discovering and controlling a WildFly 18.x runtime instance.";

	public static final String WF17_ID = IServerConstants.SERVER_WILDFLY_170;
	public static final String WF17_NAME = "WildFly 17.x";
	public static final String WF17_DESC = "A server adapter capable of discovering and controlling a WildFly 17.x runtime instance.";

	public static final String WF16_ID = IServerConstants.SERVER_WILDFLY_160;
	public static final String WF16_NAME = "WildFly 16.x";
	public static final String WF16_DESC = "A server adapter capable of discovering and controlling a WildFly 16.x runtime instance.";

	public static final String WF15_ID = IServerConstants.SERVER_WILDFLY_150;
	public static final String WF15_NAME = "WildFly 15.x";
	public static final String WF15_DESC = "A server adapter capable of discovering and controlling a WildFly 15.x runtime instance.";

	public static final String WF14_ID = IServerConstants.SERVER_WILDFLY_140;
	public static final String WF14_NAME = "WildFly 14.x";
	public static final String WF14_DESC = "A server adapter capable of discovering and controlling a WildFly 14.x runtime instance.";

	public static final String WF13_ID = IServerConstants.SERVER_WILDFLY_130;
	public static final String WF13_NAME = "WildFly 13.x";
	public static final String WF13_DESC = "A server adapter capable of discovering and controlling a WildFly 13.x runtime instance.";

	public static final String WF12_ID = IServerConstants.SERVER_WILDFLY_120;
	public static final String WF12_NAME = "WildFly 12.x";
	public static final String WF12_DESC = "A server adapter capable of discovering and controlling a WildFly 12.x runtime instance.";

	public static final String WF11_ID = IServerConstants.SERVER_WILDFLY_110;
	public static final String WF11_NAME = "WildFly 11.x";
	public static final String WF11_DESC = "A server adapter capable of discovering and controlling a WildFly 11.x runtime instance.";

	public static final String WF10_ID = IServerConstants.SERVER_WILDFLY_100;
	public static final String WF10_NAME = "WildFly 10.x";
	public static final String WF10_DESC = "A server adapter capable of discovering and controlling a WildFly 10.x runtime instance.";

	public static final String WF9_ID = IServerConstants.SERVER_WILDFLY_90;
	public static final String WF9_NAME = "WildFly 9.x";
	public static final String WF9_DESC = "A server adapter capable of discovering and controlling a WildFly 9.x runtime instance.";

	public static final String WF8_ID = IServerConstants.SERVER_WILDFLY_80;
	public static final String WF8_NAME = "WildFly 8.x";
	public static final String WF8_DESC = "A server adapter capable of discovering and controlling a WildFly 8.x runtime instance.";

	public static final String WF71_ID = IServerConstants.SERVER_AS_71;
	public static final String WF71_NAME = "JBoss AS 7.1";
	public static final String WF71_DESC = "A server adapter capable of discovering and controlling a JBoss 7.1 runtime instance.";

	public static final String WF70_ID = IServerConstants.SERVER_AS_70;
	public static final String WF70_NAME = "JBoss AS 7.0";
	public static final String WF70_DESC = "A server adapter capable of discovering and controlling a JBoss 7.0 runtime instance.";

	public static final String AS60_ID = IServerConstants.SERVER_AS_60;
	public static final String AS60_NAME = "JBoss AS 6.0";
	public static final String AS60_DESC = "A server adapter capable of discovering and controlling a JBoss 6.0 runtime instance.";

	public static final String AS51_ID = IServerConstants.SERVER_AS_51;
	public static final String AS51_NAME = "JBoss AS 5.1";
	public static final String AS51_DESC = "A server adapter capable of discovering and controlling a JBoss 5.1 runtime instance.";

	public static final String AS50_ID = IServerConstants.SERVER_AS_50;
	public static final String AS50_NAME = "JBoss AS 5.0";
	public static final String AS50_DESC = "A server adapter capable of discovering and controlling a JBoss 5.0 runtime instance.";

	public static final String AS42_ID = IServerConstants.SERVER_AS_42;
	public static final String AS42_NAME = "JBoss AS 4.2";
	public static final String AS42_DESC = "A server adapter capable of discovering and controlling a JBoss 4.2 runtime instance.";

	public static final String AS40_ID = IServerConstants.SERVER_AS_40;
	public static final String AS40_NAME = "JBoss AS 4.0";
	public static final String AS40_DESC = "A server adapter capable of discovering and controlling a JBoss 4.0 runtime instance.";

	public static final String AS32_ID = IServerConstants.SERVER_AS_32;
	public static final String AS32_NAME = "JBoss AS 3.2";
	public static final String AS32_DESC = "A server adapter capable of discovering and controlling a JBoss 3.2 runtime instance.";
	
	
	
	public static final String EAP43_ID = IServerConstants.SERVER_EAP_43;
	public static final String EAP43_NAME = "JBoss EAP 4.3";
	public static final String EAP43_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 4.3 runtime instance.";

	public static final String EAP50_ID = IServerConstants.SERVER_EAP_50;
	public static final String EAP50_NAME = "JBoss EAP 5.0";
	public static final String EAP50_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 5.0 runtime instance.";

	public static final String EAP60_ID = IServerConstants.SERVER_EAP_60;
	public static final String EAP60_NAME = "JBoss EAP 6.0";
	public static final String EAP60_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 6.0 runtime instance.";

	public static final String EAP61_ID = IServerConstants.SERVER_EAP_61;
	public static final String EAP61_NAME = "JBoss EAP 6.1";
	public static final String EAP61_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 6.1 runtime instance.";

	public static final String EAP70_ID = IServerConstants.SERVER_EAP_70;
	public static final String EAP70_NAME = "JBoss EAP 7.0";
	public static final String EAP70_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 7.0 runtime instance.";

	public static final String EAP71_ID = IServerConstants.SERVER_EAP_71;
	public static final String EAP71_NAME = "JBoss EAP 7.1";
	public static final String EAP71_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 7.1 runtime instance.";

	public static final String EAP72_ID = IServerConstants.SERVER_EAP_72;
	public static final String EAP72_NAME = "JBoss EAP 7.2";
	public static final String EAP72_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 7.2 runtime instance.";

	public static final String EAP73_ID = IServerConstants.SERVER_EAP_73;
	public static final String EAP73_NAME = "JBoss EAP 7.3";
	public static final String EAP73_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 7.3 runtime instance.";

	
}

==> site-0.23.11.Final.zip: src/main/java/org/jboss/tools/rsp/server/wildfly/servertype/impl/ServerTypeStringConstants.java <==
/*******************************************************************************
 * Copyright (c) 2018-2019 Red Hat, Inc. Distributed under license by Red Hat, Inc.
 * All rights reserved. This program is made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/epl-v20.html
 * 
 * Contributors: Red Hat, Inc.
 ******************************************************************************/
package org.jboss.tools.rsp.server.wildfly.servertype.impl;

import org.jboss.tools.rsp.server.wildfly.beans.impl.IServerConstants;

public interface ServerTypeStringConstants {
	// NEW_SERVER_ADAPTER 
	public static final String WF23_ID = IServerConstants.SERVER_WILDFLY_230;
	public static final String WF23_NAME = "WildFly 23.x";
	public static final String WF23_DESC = "A server adapter capable of discovering and controlling a WildFly 23.x runtime instance.";

	public static final String WF22_ID = IServerConstants.SERVER_WILDFLY_220;
	public static final String WF22_NAME = "WildFly 22.x";
	public static final String WF22_DESC = "A server adapter capable of discovering and controlling a WildFly 22.x runtime instance.";

	public static final String WF21_ID = IServerConstants.SERVER_WILDFLY_210;
	public static final String WF21_NAME = "WildFly 21.x";
	public static final String WF21_DESC = "A server adapter capable of discovering and controlling a WildFly 21.x runtime instance.";

	public static final String WF20_ID = IServerConstants.SERVER_WILDFLY_200;
	public static final String WF20_NAME = "WildFly 20.x";
	public static final String WF20_DESC = "A server adapter capable of discovering and controlling a WildFly 20.x runtime instance.";

	public static final String WF19_ID = IServerConstants.SERVER_WILDFLY_190;
	public static final String WF19_NAME = "WildFly 19.x";
	public static final String WF19_DESC = "A server adapter capable of discovering and controlling a WildFly 19.x runtime instance.";

	public static final String WF18_ID = IServerConstants.SERVER_WILDFLY_180;
	public static final String WF18_NAME = "WildFly 18.x";
	public static final String WF18_DESC = "A server adapter capable of discovering and controlling a WildFly 18.x runtime instance.";

	public static final String WF17_ID = IServerConstants.SERVER_WILDFLY_170;
	public static final String WF17_NAME = "WildFly 17.x";
	public static final String WF17_DESC = "A server adapter capable of discovering and controlling a WildFly 17.x runtime instance.";

	public static final String WF16_ID = IServerConstants.SERVER_WILDFLY_160;
	public static final String WF16_NAME = "WildFly 16.x";
	public static final String WF16_DESC = "A server adapter capable of discovering and controlling a WildFly 16.x runtime instance.";

	public static final String WF15_ID = IServerConstants.SERVER_WILDFLY_150;
	public static final String WF15_NAME = "WildFly 15.x";
	public static final String WF15_DESC = "A server adapter capable of discovering and controlling a WildFly 15.x runtime instance.";

	public static final String WF14_ID = IServerConstants.SERVER_WILDFLY_140;
	public static final String WF14_NAME = "WildFly 14.x";
	public static final String WF14_DESC = "A server adapter capable of discovering and controlling a WildFly 14.x runtime instance.";

	public static final String WF13_ID = IServerConstants.SERVER_WILDFLY_130;
	public static final String WF13_NAME = "WildFly 13.x";
	public static final String WF13_DESC = "A server adapter capable of discovering and controlling a WildFly 13.x runtime instance.";

	public static final String WF12_ID = IServerConstants.SERVER_WILDFLY_120;
	public static final String WF12_NAME = "WildFly 12.x";
	public static final String WF12_DESC = "A server adapter capable of discovering and controlling a WildFly 12.x runtime instance.";

	public static final String WF11_ID = IServerConstants.SERVER_WILDFLY_110;
	public static final String WF11_NAME = "WildFly 11.x";
	public static final String WF11_DESC = "A server adapter capable of discovering and controlling a WildFly 11.x runtime instance.";

	public static final String WF10_ID = IServerConstants.SERVER_WILDFLY_100;
	public static final String WF10_NAME = "WildFly 10.x";
	public static final String WF10_DESC = "A server adapter capable of discovering and controlling a WildFly 10.x runtime instance.";

	public static final String WF9_ID = IServerConstants.SERVER_WILDFLY_90;
	public static final String WF9_NAME = "WildFly 9.x";
	public static final String WF9_DESC = "A server adapter capable of discovering and controlling a WildFly 9.x runtime instance.";

	public static final String WF8_ID = IServerConstants.SERVER_WILDFLY_80;
	public static final String WF8_NAME = "WildFly 8.x";
	public static final String WF8_DESC = "A server adapter capable of discovering and controlling a WildFly 8.x runtime instance.";

	public static final String WF71_ID = IServerConstants.SERVER_AS_71;
	public static final String WF71_NAME = "JBoss AS 7.1";
	public static final String WF71_DESC = "A server adapter capable of discovering and controlling a JBoss 7.1 runtime instance.";

	public static final String WF70_ID = IServerConstants.SERVER_AS_70;
	public static final String WF70_NAME = "JBoss AS 7.0";
	public static final String WF70_DESC = "A server adapter capable of discovering and controlling a JBoss 7.0 runtime instance.";

	public static final String AS60_ID = IServerConstants.SERVER_AS_60;
	public static final String AS60_NAME = "JBoss AS 6.0";
	public static final String AS60_DESC = "A server adapter capable of discovering and controlling a JBoss 6.0 runtime instance.";

	public static final String AS51_ID = IServerConstants.SERVER_AS_51;
	public static final String AS51_NAME = "JBoss AS 5.1";
	public static final String AS51_DESC = "A server adapter capable of discovering and controlling a JBoss 5.1 runtime instance.";

	public static final String AS50_ID = IServerConstants.SERVER_AS_50;
	public static final String AS50_NAME = "JBoss AS 5.0";
	public static final String AS50_DESC = "A server adapter capable of discovering and controlling a JBoss 5.0 runtime instance.";

	public static final String AS42_ID = IServerConstants.SERVER_AS_42;
	public static final String AS42_NAME = "JBoss AS 4.2";
	public static final String AS42_DESC = "A server adapter capable of discovering and controlling a JBoss 4.2 runtime instance.";

	public static final String AS40_ID = IServerConstants.SERVER_AS_40;
	public static final String AS40_NAME = "JBoss AS 4.0";
	public static final String AS40_DESC = "A server adapter capable of discovering and controlling a JBoss 4.0 runtime instance.";

	public static final String AS32_ID = IServerConstants.SERVER_AS_32;
	public static final String AS32_NAME = "JBoss AS 3.2";
	public static final String AS32_DESC = "A server adapter capable of discovering and controlling a JBoss 3.2 runtime instance.";
	
	
	
	public static final String EAP43_ID = IServerConstants.SERVER_EAP_43;
	public static final String EAP43_NAME = "JBoss EAP 4.3";
	public static final String EAP43_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 4.3 runtime instance.";

	public static final String EAP50_ID = IServerConstants.SERVER_EAP_50;
	public static final String EAP50_NAME = "JBoss EAP 5.0";
	public static final String EAP50_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 5.0 runtime instance.";

	public static final String EAP60_ID = IServerConstants.SERVER_EAP_60;
	public static final String EAP60_NAME = "JBoss EAP 6.0";
	public static final String EAP60_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 6.0 runtime instance.";

	public static final String EAP61_ID = IServerConstants.SERVER_EAP_61;
	public static final String EAP61_NAME = "JBoss EAP 6.1";
	public static final String EAP61_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 6.1 runtime instance.";

	public static final String EAP70_ID = IServerConstants.SERVER_EAP_70;
	public static final String EAP70_NAME = "JBoss EAP 7.0";
	public static final String EAP70_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 7.0 runtime instance.";

	public static final String EAP71_ID = IServerConstants.SERVER_EAP_71;
	public static final String EAP71_NAME = "JBoss EAP 7.1";
	public static final String EAP71_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 7.1 runtime instance.";

	public static final String EAP72_ID = IServerConstants.SERVER_EAP_72;
	public static final String EAP72_NAME = "JBoss EAP 7.2";
	public static final String EAP72_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 7.2 runtime instance.";

	public static final String EAP73_ID = IServerConstants.SERVER_EAP_73;
	public static final String EAP73_NAME = "JBoss EAP 7.3";
	public static final String EAP73_DESC = "A server adapter capable of discovering and controlling a JBoss EAP 7.3 runtime instance.";

	
}
